@@ -1,5 +1,4 @@
 from scrapingant_client.client import ScrapingAntClient
-from scrapingant_client.constants import ProxyCountry
 from scrapingant_client.cookie import Cookie
 from scrapingant_client.errors import (
     ScrapingantClientException,
@@ -11,7 +10,6 @@ from scrapingant_client.response import Response
 
 __all__ = [
     'ScrapingAntClient',
-    'ProxyCountry',
     'Cookie',
     'ScrapingantClientException',
     'ScrapingantInvalidTokenException',
